@@ -3,4 +3,4 @@ from bolinette.extensions import BolinetteExtension, Extensions
 import bolinette.defaults
 import bolinette.init
 import bolinette.commands
-from bolinette.bolinette import Bolinette
+from bolinette.bolinette import Bolinette, main_func
