@@ -5,14 +5,16 @@ from bolinette import Bolinette, Console
 from bolinette.utils import paths, files
 
 
-def _find_module():
-    manifest = files.read_manifest(paths.cwd()) or {}
+def _find_module(path: str):
+    manifest = files.read_manifest(path) or {}
     return manifest.get('module', None)
 
 
-def _get_blnt_instance(console: Console):
-    module_name = _find_module()
-    if module_name is not None and paths.exists(paths.join(paths.cwd(), module_name)):
+def _get_blnt_instance(console: Console, path: str):
+    module_name = _find_module(path)
+    if module_name is not None and paths.exists(paths.join(path, module_name)):
+        if path not in sys.path:
+            sys.path.append(path)
         module = importlib.import_module(module_name)
         main_func = next(iter([f for f in module.__dict__.values()
                                if callable(f) and getattr(f, '__blnt__', None) == '__blnt_main__']), None)
@@ -29,7 +31,7 @@ def _get_blnt_instance(console: Console):
 
 
 def main():
-    _blnt = _get_blnt_instance(Console())
+    _blnt = _get_blnt_instance(Console(), paths.cwd())
     _blnt.exec_cmd_args()
 
 
